Index: include/asterisk.h
===================================================================
--- include/asterisk.h	(revision 150728)
+++ include/asterisk.h	(working copy)
@@ -60,6 +60,24 @@
  */
 void ast_unregister_atexit(void (*func)(void));
 
+/*!
+ * \brief Register a function to be executed after Asterisk started.
+ * \param func The callback function to use.
+ *
+ * \retval 0 on success.
+ * \retval -1 on error.
+ *
+ * This function is called after all modules are loaded and the core initialization
+ * is done. It's run just before the core logs 'Asterisk Ready' on the console.
+ */
+int ast_register_atstart(void (*func)(void));
+
+/*!
+ * \brief Unregister a function registered with ast_register_atstarted().
+ * \param func The callback function to unregister.
+ */
+void ast_unregister_atstart(void (*func)(void));
+
 #if !defined(LOW_MEMORY)
 /*!
  * \brief Register the version of a source code file with the core.
Index: main/asterisk.c
===================================================================
--- main/asterisk.c	(revision 150728)
+++ main/asterisk.c	(working copy)
@@ -184,6 +184,13 @@
 
 static AST_RWLIST_HEAD_STATIC(atexits, ast_atexit);
 
+struct ast_atstart {
+	void (*func)(void);
+	AST_LIST_ENTRY(ast_atstart) list;
+};
+
+static AST_LIST_HEAD_STATIC(atstarts, ast_atstart);
+
 struct timeval ast_startuptime;
 struct timeval ast_lastreloadtime;
 
@@ -804,6 +811,44 @@
 		free(ae);
 }
 
+int ast_register_atstart(void (*func)(void))
+{
+	struct ast_atstart *ae;
+
+	if (!(ae = ast_calloc(1, sizeof(*ae)))) {
+		return -1;
+	}
+
+	ae->func = func;
+
+	ast_unregister_atstart(func);
+
+	AST_LIST_LOCK(&atstarts);
+	AST_LIST_INSERT_HEAD(&atstarts, ae, list);
+	AST_LIST_UNLOCK(&atstarts);
+
+	return 0;
+}
+
+void ast_unregister_atstart(void (*func)(void))
+{
+	struct ast_atstart *ae = NULL;
+
+	AST_LIST_LOCK(&atstarts);
+	AST_LIST_TRAVERSE_SAFE_BEGIN(&atstarts, ae, list) {
+		if (ae->func == func) {
+			AST_LIST_REMOVE_CURRENT(list);
+			break;
+		}
+	}
+	AST_LIST_TRAVERSE_SAFE_END;
+	AST_LIST_UNLOCK(&atstarts);
+
+	if (ae) {
+		ast_free(ae);
+	}
+}
+
 /* Sending commands from consoles back to the daemon requires a terminating NULL */
 static int fdsend(int fd, const char *s)
 {
@@ -1326,6 +1371,18 @@
 	AST_RWLIST_UNLOCK(&atexits);
 }
 
+static void ast_run_atstarts(void)
+{
+	struct ast_atstart *ae;
+	AST_LIST_LOCK(&atstarts);
+	AST_LIST_TRAVERSE(&atstarts, ae, list) {
+		if (ae->func) {
+			ae->func();
+		}
+	}
+	AST_LIST_UNLOCK(&atstarts);
+}
+
 static void quit_handler(int num, int niceness, int safeshutdown, int restart)
 {
 	char filename[80] = "";
@@ -3400,6 +3457,9 @@
 
 	dnsmgr_start_refresh();
 
+	/* run commands for post startup */
+	ast_run_atstarts();
+
 	/* We might have the option of showing a console, but for now just
 	   do nothing... */
 	if (ast_opt_console && !option_verbose)
